@@ -35,11 +35,11 @@ class PlotMethods(object):
 
         if table.flavor == "lattice" and kind in ["textedge"]:
             raise NotImplementedError(
-                "Lattice flavor does not support kind='{}'".format(kind)
+                f"Lattice flavor does not support kind='{kind}'"
             )
         elif table.flavor == "stream" and kind in ["joint", "line"]:
             raise NotImplementedError(
-                "Stream flavor does not support kind='{}'".format(kind)
+                f"Stream flavor does not support kind='{kind}'"
             )
 
         plot_method = getattr(self, kind)
